==> cf-report-image-toolbox-1.0.3.tgz: package/src/api/codefresh.ts <==
import _ from 'lodash'
import { ClientError, gql, GraphQLClient } from 'graphql-request'
import axios from 'axios'
import chalk from 'chalk'

export class CodefreshAPI {
  private axiosClient
  private graphQLClient

  constructor(host = 'https://g.codefresh.io', apiKey) {
    this.graphQLClient = new GraphQLClient(`${host}/2.0/api/graphql`, {
      headers: {
        /* eslint-disable-next-line @typescript-eslint/naming-convention */
        'Authorization': apiKey,
      },
    })
    this.axiosClient =  axios.create({
      baseURL: `${host}/api`,
      headers: {
        /* eslint-disable-next-line @typescript-eslint/naming-convention */
        'Authorization': `Bearer ${apiKey}`
      },
    })
  }

  async getContext(name: string, type?: string) {
    if (type && ![ 'git', 'atlassian' ].includes(type)) {
      throw new Error(`Wrong context type: ${type}`)
    }

    return this.axiosClient(`/contexts/${name}?decrypt=true${type ? '&regex=true&type=' + type : ''}`)
      .then(response => response.data)
      .catch(_handleQlError(''))
  }

  async getUserInfo() {
    return this.axiosClient(`/user`)
      .then(response => response.data)
      .catch(_handleQlError(''))
  }

  async getFeature(feature) {
    try {
      const user = await this.getUserInfo()
      const accountName = _.get(user, 'activeAccountName')
      const accounts = _.get(user, 'account', [])
      const activeAccount = _.find(accounts, (account) => account.name === accountName)
      return _.get(activeAccount, `features.${feature}`, false)
    } catch (error) {
      console.log(`Unable to get feature ${feature}. ${error.message}`)
      return false
    }
  }

  async createImageBinary(imageBinaryVars) {
    const binaryMutation = gql`mutation($imageBinary: ImageBinaryInput!){
        createImageBinary(imageBinary: $imageBinary) {
            id,
            imageName,
            workflowName
        }
    }`
    return this.graphQLClient.request(binaryMutation, imageBinaryVars)
      .catch(_handleQlError('failed to create image binary'))
  }

  async createImageRegistry(imageRegistryVars) {
    const registryMutation = gql`mutation($imageRegistry: ImageRegistryInput!) {
        createImageRegistry(imageRegistry: $imageRegistry) {
            binaryId
            repoDigest
        }
    }`
    return this.graphQLClient.request(registryMutation, imageRegistryVars)
      .catch(_handleQlError('failed to create image registry'))
  }

  async createImageLayers(imageLayersVars) {
    const imageLayersMutation = gql`mutation($imageLayers: ImageLayersInput!) {
        createImageLayers(imageLayers: $imageLayers) {
            accountId
            created
            image
            layerDigests
            layers {
                created
                instruction
                size
                args
            }
        }
    }`
    return this.graphQLClient.request(imageLayersMutation, imageLayersVars)
      .catch(_handleQlError('failed to create image layers'))
  }

  async patchImageWithGitBranchData(imageName,  branch) {
    console.log(chalk.green(`patching image with data from branch: ${branch.name}`))
    const patchImageBinaryMutation = gql`mutation patchImageBinary($imagePatch: ImageBinaryPatchInput!, $imageName: String) {
        patchImageBinary(imagePatch: $imagePatch, imageName: $imageName) {
            imageName
        }
    }`
    const vars = {
      imageName,
      imagePatch: {
        branch: branch.name,
        commit: branch.commit,
        commitMsg: branch.commitMsg,
        commitURL: branch.commitURL,
        author: {
          username: branch.committerUsername
        }
      }
    }

    return this.graphQLClient.request(patchImageBinaryMutation, vars)
      .catch(_handleQlError('Failed to patch image with branch data'))
  }

  async createPullRequestAnnotationClassic(image, pullRequest) {
    console.log(chalk.green(`Create pull request ${pullRequest.number}=${pullRequest.url}, image ${image}`))

    return this.axiosClient(`/annotations`, {
      method: 'POST',
      data: {
        entityId: image,
        entityType: 'image-prs',
        key: `#${pullRequest.number}`,
        value: {
          url: pullRequest.url,
          title: pullRequest.title,
          committers: pullRequest.committers
        },
        bigValue: {
          firstCommitDate: pullRequest.firstCommitDate,
          lastCommitDate: pullRequest.lastCommitDate,
          prDate: pullRequest.prDate,
          branch: pullRequest.branch,
          commits: pullRequest.commits,
        }
      },
    })
      .then(response => response.data)
      .catch(_handleQlError(''))
  }

  async createPullRequestAnnotation(imageName, pullRequest) {
    console.log(chalk.green(`creating pull request annotation ${pullRequest.number}=${pullRequest.url}`))

    const saveAnnotationMutation = gql`mutation saveAnnotation($annotation: AnnotationArgs!) {
        saveAnnotation(annotation: $annotation)
    }`
    const vars = {
      annotation: {
        logicEntityId: { id: imageName },
        entityType: 'image',
        key: `#${pullRequest.number}`,
        type: 'pr',
        pullRequestValue: {
          url: pullRequest.url,
          title: pullRequest.title,
          committers: pullRequest.committers,
          commits: (pullRequest.commits || []).map(c => ({
            url: c.url,
            userName: c.userName,
            sha: c.sha,
            message: c.message,
            commitDate: c.commitDate
          }))
        }
      }
    }
    return this.graphQLClient.request(saveAnnotationMutation, vars)
      .catch(_handleQlError('Failed to create pr annotation'))
  }

  async createIssueAnnotationClassic(image: string, issue) {
    console.log(`Create issue request ${issue.number}=${issue.url}, image: ${image}`)

    return this.axiosClient(`/annotations`, {
      method: 'POST',
      data: {
        entityId: image,
        entityType: 'image-issues',
        key: `${issue.number}`,
        value: {
          url: issue.url,
          title: issue.title
        }
      },
    })
      .then(response => response.data)
      .catch(_handleQlError(''))
  }

  async createIssueAnnotation(imageName, issue) {
    console.log(chalk.green(`creating issue annotation ${issue.number}=${issue.url}, image: ${imageName}`))
    const saveAnnotationMutation = gql`mutation saveAnnotation($annotation: AnnotationArgs!) {
        saveAnnotation(annotation: $annotation)
    }`
    const vars = {
      annotation: {
        logicEntityId: { 'id': imageName },
        entityType: 'image',
        key: `${issue.number}`,
        type: 'issue',
        issueValue: {
          url: issue.url,
          title: issue.title,
          assignee: issue.assignee,
          avatarURL: issue.avatarURL,
          status: issue.status
        },
      }
    }
    return this.graphQLClient.request(saveAnnotationMutation, vars)
      .catch(_handleQlError('Failed to create issue annotation'))
  }

  async getJiraIssue(context, issueKey) {
    return this.axiosClient(`/atlassian/issues/${issueKey}?jira-context=${context}`)
      .then(response => response.data)
      .catch(_handleQlError(''))
  }

}

const _handleQlError = (prefix) => (e: any) => {
  let formattedMessage
  if (e instanceof ClientError) {
    if (e.response.status !== 200) {
      formattedMessage = e.response.error
    } else {
      const qlErrorMessage = _.get<ClientError, string>(e, 'response.errors.0.message')
      if (qlErrorMessage) {
        formattedMessage = qlErrorMessage
      }
    }
  }
  throw new Error(prefix
    ? `${prefix} (${formattedMessage || e.message})`
    : formattedMessage || e.message)
}

==> cf-report-image-toolbox-1.0.7.tgz: package/src/api/codefresh.ts <==
import _ from 'lodash'
import { ClientError, gql, GraphQLClient } from 'graphql-request'
import axios from 'axios'
import chalk from 'chalk'

export class CodefreshAPI {
  private axiosClient
  private graphQLClient

  constructor(host = 'https://g.codefresh.io', apiKey) {
    this.graphQLClient = new GraphQLClient(`${host}/2.0/api/graphql`, {
      headers: {
        /* eslint-disable-next-line @typescript-eslint/naming-convention */
        'Authorization': apiKey,
      },
    })
    this.axiosClient =  axios.create({
      baseURL: `${host}/api`,
      headers: {
        /* eslint-disable-next-line @typescript-eslint/naming-convention */
        'Authorization': `Bearer ${apiKey}`
      },
    })
  }

  async getContext(name: string, type?: string) {
    if (type && ![ 'git', 'atlassian' ].includes(type)) {
      throw new Error(`Wrong context type: ${type}`)
    }

    return this.axiosClient(`/contexts/${name}?decrypt=true${type ? '&regex=true&type=' + type : ''}`)
      .then(response => response.data)
      .catch(_handleQlError(''))
  }

  async getUserInfo() {
    return this.axiosClient(`/user`)
      .then(response => response.data)
      .catch(_handleQlError(''))
  }

  async getFeature(feature) {
    try {
      const user = await this.getUserInfo()
      const accountName = _.get(user, 'activeAccountName')
      const accounts = _.get(user, 'account', [])
      const activeAccount = _.find(accounts, (account) => account.name === accountName)
      return _.get(activeAccount, `features.${feature}`, false)
    } catch (error) {
      console.log(`Unable to get feature ${feature}. ${error.message}`)
      return false
    }
  }

  async createImageBinary(imageBinaryVars) {
    const binaryMutation = gql`mutation($imageBinary: ImageBinaryInput!){
        createImageBinary(imageBinary: $imageBinary) {
            id,
            imageName,
            workflowName
        }
    }`
    return this.graphQLClient.request(binaryMutation, imageBinaryVars)
      .catch(_handleQlError('failed to create image binary'))
  }

  async createImageRegistry(imageRegistryVars) {
    const registryMutation = gql`mutation($imageRegistry: ImageRegistryInput!) {
        createImageRegistry(imageRegistry: $imageRegistry) {
            binaryId
            repoDigest
        }
    }`
    return this.graphQLClient.request(registryMutation, imageRegistryVars)
      .catch(_handleQlError('failed to create image registry'))
  }

  async createImageLayers(imageLayersVars) {
    const imageLayersMutation = gql`mutation($imageLayers: ImageLayersInput!) {
        createImageLayers(imageLayers: $imageLayers) {
            accountId
            created
            image
            layerDigests
            layers {
                created
                instruction
                size
                args
            }
        }
    }`
    return this.graphQLClient.request(imageLayersMutation, imageLayersVars)
      .catch(_handleQlError('failed to create image layers'))
  }

  async patchImageWithGitBranchData(imageName,  branch) {
    console.log(chalk.green(`patching image with data from branch: ${branch.name}`))
    const patchImageBinaryMutation = gql`mutation patchImageBinary($imagePatch: ImageBinaryPatchInput!, $imageName: String) {
        patchImageBinary(imagePatch: $imagePatch, imageName: $imageName) {
            imageName
        }
    }`
    const vars = {
      imageName,
      imagePatch: {
        branch: branch.name,
        commit: branch.commit,
        commitMsg: branch.commitMsg,
        commitURL: branch.commitURL,
        author: {
          username: branch.committerUsername
        }
      }
    }

    return this.graphQLClient.request(patchImageBinaryMutation, vars)
      .catch(_handleQlError('Failed to patch image with branch data'))
  }

  async createPullRequestAnnotationClassic(image, pullRequest) {
    console.log(chalk.green(`Create pull request ${pullRequest.number}=${pullRequest.url}, image ${image}`))

    return this.axiosClient(`/annotations`, {
      method: 'POST',
      data: {
        entityId: image,
        entityType: 'image-prs',
        key: `#${pullRequest.number}`,
        value: {
          url: pullRequest.url,
          title: pullRequest.title,
          committers: pullRequest.committers
        },
        bigValue: {
          firstCommitDate: pullRequest.firstCommitDate,
          lastCommitDate: pullRequest.lastCommitDate,
          prDate: pullRequest.prDate,
          branch: pullRequest.branch,
          commits: pullRequest.commits,
        }
      },
    })
      .then(response => response.data)
      .catch(_handleQlError(''))
  }

  async createPullRequestAnnotation(key, imageName, pullRequest) {
    console.log(chalk.green(`creating pull request annotation ${pullRequest.number}=${pullRequest.url}`))

    const saveAnnotationMutation = gql`mutation saveAnnotation($annotation: AnnotationArgs!) {
        saveAnnotation(annotation: $annotation)
    }`
    const vars = {
      annotation: {
        logicEntityId: { id: imageName },
        entityType: 'image',
        key,
        type: 'pr',
        pullRequestValue: {
          id: `#${pullRequest.number}`,
          url: pullRequest.url,
          title: pullRequest.title,
          committers: pullRequest.committers,
          commits: (pullRequest.commits || []).map(c => ({
            url: c.url,
            userName: c.userName,
            sha: c.sha,
            message: c.message,
            commitDate: c.commitDate
          }))
        }
      }
    }
    return this.graphQLClient.request(saveAnnotationMutation, vars)
      .catch(_handleQlError('Failed to create pr annotation'))
  }

  async createIssueAnnotationClassic(image: string, issue) {
    console.log(`Create issue request ${issue.number}=${issue.url}, image: ${image}`)

    return this.axiosClient(`/annotations`, {
      method: 'POST',
      data: {
        entityId: image,
        entityType: 'image-issues',
        key: `${issue.number}`,
        value: {
          url: issue.url,
          title: issue.title
        }
      },
    })
      .then(response => response.data)
      .catch(_handleQlError(''))
  }

  async createIssueAnnotation(imageName, issue) {
    console.log(chalk.green(`creating issue annotation ${issue.number}=${issue.url}, image: ${imageName}`))
    const saveAnnotationMutation = gql`mutation saveAnnotation($annotation: AnnotationArgs!) {
        saveAnnotation(annotation: $annotation)
    }`
    const vars = {
      annotation: {
        logicEntityId: { 'id': imageName },
        entityType: 'image',
        key: `${issue.number}`,
        type: 'issue',
        issueValue: {
          url: issue.url,
          title: issue.title,
          assignee: issue.assignee,
          avatarURL: issue.avatarURL,
          status: issue.status
        },
      }
    }
    return this.graphQLClient.request(saveAnnotationMutation, vars)
      .catch(_handleQlError('Failed to create issue annotation'))
  }

  async getJiraIssue(context, issueKey) {
    return this.axiosClient(`/atlassian/issues/${issueKey}?jira-context=${context}`)
      .then(response => response.data)
      .catch(_handleQlError(''))
  }

}

const _handleQlError = (prefix) => (e: any) => {
  let formattedMessage
  if (e instanceof ClientError) {
    if (e.response.status !== 200) {
      formattedMessage = e.response.error
    } else {
      const qlErrorMessage = _.get<ClientError, string>(e, 'response.errors.0.message')
      if (qlErrorMessage) {
        formattedMessage = qlErrorMessage
      }
    }
  }
  throw new Error(prefix
    ? `${prefix} (${formattedMessage || e.message})`
    : formattedMessage || e.message)
}
